@@ -11,7 +11,7 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
@@ -33,7 +33,7 @@ G_BEGIN_DECLS
 
 typedef struct _GsfInputTextline GsfInputTextline;
 
-GType gsf_input_textline_get_type      (void) G_GNUC_CONST;
+GType gsf_input_textline_get_type      (void);
 /* void  gsf_input_textline_register_type (GTypeModule *module); glib dynamic types are not thread safe */
 
 
